@@ -3,17 +3,6 @@
 //ff-c++-cpp-dep: 
 //  for Super4.0 library   
 #include "ff++.hpp"
-/*
-#include  <iostream>
-using namespace std;
-
-#include "rgraph.hpp"
-#include "error.hpp"
-#include "AFunction.hpp"
-
-//#include "lex.hpp"
-#include "MatriceCreuse_tpl.hpp"
-*/
 #include "slu_ddefs.h"
 #include "superlu_enum_consts.h"
 #define GlobalLU_t GlobalLU_txxxx
@@ -529,6 +518,7 @@ public:
     xarow=AA.lg;
 
     /* FreeFem++ use Morse Format */ 
+    // FFCS - "this->" required by g++ 4.7
     this->CompRow_to_CompCol(m, n, nnz, arow, asubrow, xarow, 
 		       &a, &asub, &xa);
 
@@ -578,6 +568,7 @@ public:
 
     Dtype_t R_SLU = SuperLUDriver<R>::R_SLU_T(); 
 
+    // FFCS - "this->" required by g++ 4.7
     this->Create_CompCol_Matrix(&A, m, n, nnz, a, asub, xa, SLU_NC, R_SLU, SLU_GE);
   
     this->Create_Dense_Matrix(&B, m, 0, (R*) 0, m, SLU_DN, R_SLU, SLU_GE);
@@ -663,6 +654,7 @@ public:
 	  KN_2Ptr<R> xx(x),bb(b);
 	  // cout << " xx #### " << xx.c.N() << " "<< xx.ca.N() <<  " " << xx.ca.step << endl;
 	  //cout << " bb #### " << bb.c.N() << " "<< bb.ca.N() << " " << bb.ca.step <<endl;
+	  // FFCS - "this->" required by g++ 4.7
 	  this->Create_Dense_Matrix(&B, m, 1, bb, m, SLU_DN, R_SLU, SLU_GE);
 	  this->Create_Dense_Matrix(&X, m, 1, xx, m, SLU_DN, R_SLU, SLU_GE);
 	  
@@ -759,15 +751,6 @@ DefSparseSolver<Complex>::SparseMatSolver SparseMatSolver_C;
 // the default probleme solver 
 TypeSolveMat::TSolveMat  TypeSolveMatdefaultvalue=TypeSolveMat::defaultvalue;
 
-bool SetDefault()
-{
-    if(verbosity>1)
-	cout << " SetDefault sparse to default" << endl;
-    DefSparseSolver<double>::solver =SparseMatSolver_R;
-    DefSparseSolver<Complex>::solver =SparseMatSolver_C;
-    TypeSolveMat::defaultvalue =TypeSolveMat::SparseSolver;
-}
-
 bool SetSuperLU()
 {
     if(verbosity>1)
@@ -775,6 +758,7 @@ bool SetSuperLU()
     DefSparseSolver<double>::solver  =BuildSolverSuperLU;
     DefSparseSolver<Complex>::solver =BuildSolverSuperLU;    
     TypeSolveMat::defaultvalue =TypeSolveMatdefaultvalue;
+    return  true;
 }
 
 
@@ -787,12 +771,10 @@ Init::Init()
   SparseMatSolver_C= DefSparseSolver<Complex>::solver;
   
   if(verbosity>1)
-    cout << "\n Add: SuperLU,  defaultsolver defaultsolverSuperLU" << endl;
+    cout << "\n Add: SuperLU,  defaultsolverSuperLU" << endl;
   TypeSolveMat::defaultvalue=TypeSolveMat::SparseSolver;
   DefSparseSolver<double>::solver =BuildSolverSuperLU;
   DefSparseSolver<Complex>::solver =BuildSolverSuperLU;
-  if(! Global.Find("defaultsolver").NotNull() )
-    Global.Add("defaultsolver","(",new OneOperator0<bool>(SetDefault));
   Global.Add("defaulttoSuperLU","(",new OneOperator0<bool>(SetSuperLU));
 }
 
