@@ -89,13 +89,20 @@ using std::numeric_limits;
 template<class FElement>
 inline int  BuildMEK_KK(const int l,int *p,int *pk,int *pkk,const FElement * pKE,const FElement*pKKE)
 {
+  // routine which find common  dof on to adjacent element pKE and pKKE and make the link ..
+  // if pKKE== 0   then no  adj element
+  // the idea is find common dof, but this work only if all dot a different
+  // in on elemnt, so we can have a bug
+  //  in case of periodic boundary condition ..
+  // not correct ... F.Hecht ...
+
+  // -----
   // routine  build  les array p, pk,pkk 
   // which return number of df int 2 element pKE an pKKE
   // max l size of array p, pk, pkk
   // p[i] is the global number of freedom
   // pk[i] is is the local number in pKE ( -1 if not in pKE element)
   // pkk[i] is is the local number in pKKE ( -1 if not in pKKE element)
-  //  remark, if pKKE = 0 => 
      const FElement (*pK[2])={pKE,pKKE};
 
      int ndf=0; // number of dl
@@ -109,34 +116,48 @@ inline int  BuildMEK_KK(const int l,int *p,int *pk,int *pkk,const FElement * pKE
          
          for (int ii=0;ii<nbdf;ii++)
           {
-           p[ndf] = FEK(ii); // copy the numbering 
+           p[ndf] = 2*FEK(ii)+k; // copy the numbering
            qk[ndf] = ii;
            qkk[ndf++] = -1;
           } // end for ii
          } 
       ffassert(ndf <=l);
+    int bug=0;
    // compression suppression des doublons
+    // attention un df peu aparaitre 2 fois (CL period) dans un element ..
        Fem2D::HeapSort(p,pk,pkk,ndf);
        int k=0;  
         for(int ii=1;ii<ndf;++ii)
-          if (p[k]==p[ii]) // doublons 
+          if (p[k]/2==p[ii]/2) // doublons k,kk
             { 
               if (pkk[ii]>=0) pkk[k]=pkk[ii];
               if (pk[ii]>=0) pk[k]=pk[ii];
               assert(pk[k] >=0 && pkk[k]>=0);
             }
-           else { // copy 
+           else { // copy
+              if(p[k]==p[ii]) bug++;
               p[++k] =p[ii];
               pk[k]=pk[ii];
               pkk[k]=pkk[ii];
              }
         ndf=k+1; 
-         
+  for(int ii=0;ii<ndf;++ii)
+      p[ii]= p[ii]/2;// clean pp to revome bug(CL period)
+    if( bug && pKKE) {
+        static int count =0;
+        if( count++ < 2 && verbosity )
+        {
+        cerr << "  May be a Bug in BuildMEK_KK , the code is not safe , periodic boundary condition  on 1 element . " << bug <<  endl;
+        cerr << "  They is a problem   in this case (I am not sure) F.H.  ????" << endl;
+            cerr << "   exempt if the associed  matrix voefficient is 0. "<< endl;
+        }
+        //ffassert(0); // bof bof ... remove of case of jump in internal edge ...
+    }
    return ndf;
 } //  BuildMEK_KK
 
 template<class R,class FES>
-void MatriceElementairePleine<R,FES>::call(int k,int ie,int label,void * stack) {
+void MatriceElementairePleine<R,FES>::call(int k,int ie,int label,void * stack,void *B) {
   for (int i=0;i<this->lga;i++) 
      this->a[i]=0;
   if(this->onFace)
@@ -154,7 +175,7 @@ void MatriceElementairePleine<R,FES>::call(int k,int ie,int label,void * stack)
 	  this->n=this->m=BuildMEK_KK<FElement>(this->lnk,this->ni,this->nik,this->nikk,&Kv,0);
          int n2 =this->m*this->n; 
          for (int i=0;i<n2;i++) this->a[i]=0;
-         faceelement(*this,Kv,Kv,Kv,Kv,this->data,ie,iie,label,stack);
+         faceelement(*this,Kv,Kv,Kv,Kv,this->data,ie,iie,label,stack,reinterpret_cast<Rd*>(B));
         }
         else
         {
@@ -162,7 +183,7 @@ void MatriceElementairePleine<R,FES>::call(int k,int ie,int label,void * stack)
          this->n=this->m=BuildMEK_KK<FElement>(this->lnk,this->ni,this->nik,this->nikk,&Kv,&KKv);
         
          
-         faceelement(*this,Kv,KKv,Kv,KKv,this->data,ie,iie,label,stack);
+         faceelement(*this,Kv,KKv,Kv,KKv,this->data,ie,iie,label,stack,reinterpret_cast<Rd*>(B));
 
         }
       }
@@ -189,20 +210,20 @@ void MatriceElementairePleine<R,FES>::call(int k,int ie,int label,void * stack)
      this->m=nbdf;
      int n2 =this->m*this->n; 
      for (int i=0;i<n2;i++) this->a[i]=0;
-     element(*this,Ku,Kv,this->data,ie,label,stack);
+     element(*this,Ku,Kv,this->data,ie,label,stack,reinterpret_cast<Rd*>(B));
   }
   else 
     {
      int n2 =this->m*this->n;
      for (int i=0;i<n2;i++) this->a[i]=0;
-     element(*this,Kv,Kv,this->data,ie,label,stack);
+     element(*this,Kv,Kv,this->data,ie,label,stack,reinterpret_cast<Rd*>(B));
    // call the elementary mat 
     }  
   }  
 }
 
 template<class R,class FES>
-void MatriceElementaireSymetrique<R,FES>::call(int k,int ie,int label,void * stack) {
+void MatriceElementaireSymetrique<R,FES>::call(int k,int ie,int label,void * stack,void  *B) {
   // mise a zero de la matrice elementaire, plus sur
   for (int i=0;i<this->lga;i++) 
     this->a[i]=0;
@@ -221,7 +242,7 @@ void MatriceElementaireSymetrique<R,FES>::call(int k,int ie,int label,void * sta
 	  this->ni[i] = K(i); // copy the numbering 
 	this->m=this->n = nbdf; 
 	
-	element(*this,K,this->data,ie,label,stack); 
+	element(*this,K,this->data,ie,label,stack,static_cast<Rd*>(B));
       }// call the elementary mat 
     else
       {
