@@ -18,6 +18,6 @@ string StrVersionNumber(){
 //  buffer.precision(8);
 //  buffer<<VersionNumber();
   static char buffer[100];
-  sprintf(buffer," %9f (date Jeu 28 nov 2013 11:11:34 CET)",VersionNumber());
-  return buffer; //.str()+" (date Jeu 28 nov 2013 11:11:34 CET)" ;
+  sprintf(buffer," %9f (date Ven 11 jul 2014 21:27:24 CEST)",VersionNumber());
+  return buffer; //.str()+" (date Ven 11 jul 2014 21:27:24 CEST)" ;
 }
